@@ -88,7 +88,7 @@ Please set only one of these two options to 'True'
             full_path = os.path.join(root, filename)
             rel_path  = os.path.relpath(full_path, directory)
             arcname   = os.path.join(os.path.basename(directory), rel_path)
-            if sys.stdout.isatty() and not quiet:
+            if not quiet:
                 sys.stdout.write("adding {0}\n".format(rel_path))
                 sys.stdout.flush()
             if not qisys.sh.broken_symlink(full_path):
@@ -98,7 +98,7 @@ Please set only one of these two options to 'True'
 
 
 # pylint: disable-msg=R0914
-def _extract_zip(archive, directory, quiet, verbose):
+def _extract_zip(archive, directory, quiet, verbose, strict_mode=True):
     """Extract a zip archive into directory
 
     :param archive:   path of the archive
@@ -138,18 +138,8 @@ Please set only one of these two options to 'True'
             mess  = "Invalid member %s in archive:\n" % member.filename
             mess += "Every file must be in the same top dir (%s != %s)" % \
                 (orig_topdir, member_top_dir)
-            raise InvalidArchive(mess)
-        # By-pass buggy zipfile for python 2.6:
-        if sys.version_info < (2, 7):
-            if member.filename.endswith("/"):
-                # upstream buggy code would create an empty filename
-                # instead of a directory, thus preventing next members
-                # to be extracted
-                to_create = member.filename[:-1]
-                posix_dest_dir = qisys.sh.to_posix_path(directory)
-                to_create = posixpath.join(posix_dest_dir, to_create)
-                qisys.sh.mkdir(to_create, recursive=True)
-                continue
+            if strict_mode:
+                raise InvalidArchive(mess)
         archive_.extract(member, path=directory)
         # Fix permision on extracted file unless it is a directory
         # or if we are on windows
@@ -386,7 +376,9 @@ Please set only one of these two options to 'True'
     return archive_path
 
 
-def extract(archive, directory, algo=None, quiet=False, verbose=False):
+def extract(archive, directory, algo=None,
+                     quiet=False, verbose=False,
+                     strict_mode=True):
     """Extract a an archive into directory
 
     :param archive:   path of the archive
@@ -407,7 +399,8 @@ def extract(archive, directory, algo=None, quiet=False, verbose=False):
     archive   = qisys.sh.to_native_path(archive)
     archive   = os.path.abspath(archive)
     if algo == "zip":
-        extract_location = _extract_zip(archive, directory, quiet, verbose)
+        extract_location = _extract_zip(archive, directory, quiet, verbose,
+                                        strict_mode=strict_mode)
     else:
         extract_location = _extract_tar(archive, directory, algo, quiet, verbose)
     return extract_location
